@@ -1,10 +1,8 @@
-##' @useDynLib coRanking
-
 ## there is really no need to export this one
-euclidean <- function(X, use = 'C'){
+euclidean <- function(X, use = "C"){
     X <- as.matrix(X)
-    if(!is.double(X)) stop("X must be of type double")
-    if(use == 'C') {
+    if (!is.double(X)) stop("X must be of type double")
+    if (use == "C") {
         euclidean_C(X)
     } else {
         euclidean_R(X)
@@ -17,23 +15,25 @@ euclidean_R <- function(X) {
     res
 }
 
+##' @useDynLib coRanking C_euclidean
 euclidean_C <- function(X) {
-    .Call('euclidean', as.matrix(X))
+    .Call("C_euclidean", as.matrix(X))
 }
 
 rankmatrix_R <- function(X){
-    f <- function(x) rank(x, ties.method = 'first', na.last = FALSE)
+    f <- function(x) rank(x, ties.method = "first", na.last = FALSE)
     diag(X) <- NA
-    res <- apply(X, 1, f) 
+    res <- apply(X, 1, f)
     res <- res - 1 # in c sorting starts with 0
     dimnames(res) <- NULL
-    storage.mode(res) <- 'integer'
-    class(res) <- 'rankmatrix'
+    storage.mode(res) <- "integer"
+    class(res) <- "rankmatrix"
     res
 }
 
+##' @useDynLib coRanking C_rankmatrix
 rankmatrix_C <- function(X) {
-    .Call('rankmatrix', X)
+    .Call("C_rankmatrix", X)
 }
 
 coranking_R <- function(Ro, R) {
@@ -44,6 +44,7 @@ coranking_R <- function(Ro, R) {
     res
 }
 
+##' @useDynLib coRanking C_coranking
 coranking_C <- function(Ro, R) {
-    .Call('coranking', Ro, R)
+    .Call("C_coranking", Ro, R)
 }
